from portmgr import command_list, bcolors
import subprocess
from compose.cli.command import get_project
from compose import project
from compose.project import OneOffFilter
from operator import attrgetter

def func(action):
    directory = action['directory']
    relative = action['relative']
    
    project = get_project('.')
    
    containers = sorted(
        project.containers(stopped=False) +
        project.containers(one_off=OneOffFilter.only, stopped=False),
        key=attrgetter('name'))
        
    names = []
    for container in containers:
      names.append(container.name)
      
    index = 0
    cont_count = len(names)
    if cont_count == 0:
      print("No containers found!")
      return 1
    elif cont_count > 1:
      i = 0
      for cont in names:
        print("(" + str(i) + ") " + cont)
        i += 1
      
      while True:
        choice = input("Choose container: ")
        if choice:
          try:
            index = int(choice)
            if index >= 0 and index < cont_count:
              break
          except ValueError:
            print("Please enter a number!")
            pass
        print("Please enter a number between 0 and " + cont_count - 1 + "!")
              
    container_id = names[index]
    print("Attaching to " + container_id)
    subprocess.call(["docker", "exec", "-it", container_id, "sh"])

    # res = subprocess.call(["docker-compose", "logs", "--follow", "--tail=200"])

    # if res != 0:
        # print("Error showing logs for " + relative + "!\n")

    return 0

command_list['a'] = {
    'hlp': 'Attach to process',
    'ord': 'nrm',
    'fnc': func
}



from portmgr import command_list, bcolors
import subprocess

def func(action):
    directory = action['directory']
    relative = action['relative']

    res = subprocess.call(["docker-compose", "ps"])

    if res != 0:
        print("Error listing containers for " + relative + "!\n")

    return 0

command_list['c'] = {
    'hlp': 'List containers',
    'ord': 'nrm',
    'fnc': func
}



from portmgr import command_list
import subprocess


def func(action):
    relative = action['relative']

    res = subprocess.call(["docker-compose", "top"])

    if res != 0:
        print("Error listing processes of containers in " + relative + "!\n")

    return 0


command_list['t'] = {
    'hlp': 'List processes in containers',
    'ord': 'nrm',
    'fnc': func
}



from portmgr import command_list, bcolors
import subprocess

def func(action):
    directory = action['directory']
    relative = action['relative']

    res = subprocess.call(
            ['docker-compose', 'build',
                '--pull',
                '--force-rm',
                '--compress'
            ]
    )

    if res != 0:
        print("Error building " + relative + "!")
        return res

    res = subprocess.call(['docker-compose', 'push'])

    if res != 0:
        print("Error pushing " + relative + "!")
        return res

    # res = subprocess.call(['docker', 'system', 'prune', '--all', '--force'])

    # if res != 0:
    #     print("Error pruning system!")
    #     return res

    return res

command_list['r'] = {
    'hlp': 'build, push to registry & remove image',
    'ord': 'nrm',
    'fnc': func
}



from portmgr import command_list
import subprocess
import json
from compose.cli.command import get_project
from compose.project import OneOffFilter
from compose import project
from operator import attrgetter

def func(action):
    directory = action['directory']
    relative = action['relative']

    project = get_project('.')

    containers = sorted(
        project.containers() +
        project.containers(one_off=OneOffFilter.only, stopped=False),
        key=attrgetter('name'))

    names = []
    res = 0
    for container in containers:
      image_name = container.image_config['RepoTags'][0]
      print(f'Scanning {image_name} of {container.service}')
      scan_res = subprocess.run(['trivy', '-q', 'image', '-s', 'HIGH,CRITICAL', '--exit-code', '1', image_name], stdout=subprocess.PIPE, stderr=subprocess.STDOUT, text=True)
      if scan_res.returncode != 0:
        print('Found vulnerabilites:')
        print(scan_res.stdout)
        res = scan_res.returncode

      #print("Name: %s" % container.name)
      #names.append(container.name)
      #config_str = subprocess.check_output(["docker", "inspect", "-f", '{{json .}}', container.id], stdout=subprocess.PIPE)
      #json.loads(config_str)
      #print("IP: %s" % ip)
      #print(container.inspect)


    #ID = subprocess.run(["docker-compose", "ps", '-q'], stdout=subprocess.PIPE).stdout

    #if res != 0:
    #    print("Error listing containers for " + relative + "!\n")

    return res

command_list['v'] = {
    'hlp': 'Scan container images for vulnerabilities',
    'ord': 'nrm',
    'fnc': func
}



from setuptools import setup, find_packages

setup(
    name='portmgr',
    version='1.4.0dev0',
    url="https://github.com/Craeckie/portmgr",
    description="Simple command interface to manage multiple Docker container",
    packages=find_packages(), #['portmgr'],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    zip_safe=False,

    install_requires=[
        'docker-compose',
        'jsonschema'
    ],
    entry_points = {
        'console_scripts': [
            'portmgr = portmgr:main'
        ]
    }
)
